@@ -170,7 +170,12 @@ dBodyGetMaxAngularSpeed = loadOde('dBodyGetMaxAngularSpeed', dReal, dBodyID)
 dBodySetMaxAngularSpeed = loadOde('dBodySetMaxAngularSpeed', None, dBodyID, dReal)
 dBodyGetGyroscopicMode = loadOde('dBodyGetGyroscopicMode', c_int32, dBodyID)
 dBodySetGyroscopicMode = loadOde('dBodySetGyroscopicMode', None, dBodyID, c_int32)
-dJointCreateBall = loadOde('dJointCreateBall', dJointID, dWorldID, dJointGroupID)
+
+def dJointCreateBall(world, jointGroup):
+    if isinstance(jointGroup, int):
+        return loadOde('dJointCreateBall', dJointID, dWorldID, c_int32)(world, jointGroup)
+    else:
+        return loadOde('dJointCreateBall', dJointID, dWorldID, dJointGroupID)(world, jointGroup)
 
 def dJointCreateHinge(world, jointGroup):
     if isinstance(jointGroup, int):
@@ -185,16 +190,45 @@ def dJointCreateSlider(world, jointGroup):
         return loadOde('dJointCreateSlider', dJointID, dWorldID, dJointGroupID)(world, jointGroup)
 
 dJointCreateContact = loadOde('dJointCreateContact', dJointID, dWorldID, dJointGroupID, POINTER(dContact))
-dJointCreateHinge2 = loadOde('dJointCreateHinge2', dJointID, dWorldID, dJointGroupID)
-dJointCreateUniversal = loadOde('dJointCreateUniversal', dJointID, dWorldID, dJointGroupID)
+
+def dJointCreateHinge2(world, jointGroup):
+    if isinstance(jointGroup, int):
+        return loadOde('dJointCreateHinge2', dJointID, dWorldID, c_int32)(world, jointGroup)
+    else:
+        return loadOde('dJointCreateHinge2', dJointID, dWorldID, dJointGroupID)(world, jointGroup)
+
+def dJointCreateUniversal(world, jointGroup):
+    if isinstance(jointGroup, int):
+        return loadOde('dJointCreateUniversal', dJointID, dWorldID, c_int32)(world, jointGroup)
+    else:
+        return loadOde('dJointCreateUniversal', dJointID, dWorldID, dJointGroupID)(world, jointGroup)
+
 dJointCreatePR = loadOde('dJointCreatePR', dJointID, dWorldID, dJointGroupID)
 dJointCreatePU = loadOde('dJointCreatePU', dJointID, dWorldID, dJointGroupID)
 dJointCreatePiston = loadOde('dJointCreatePiston', dJointID, dWorldID, dJointGroupID)
-dJointCreateFixed = loadOde('dJointCreateFixed', dJointID, dWorldID, dJointGroupID)
+
+def dJointCreateFixed(world, jointGroup):
+    if isinstance(jointGroup, int):
+        return loadOde('dJointCreateFixed', dJointID, dWorldID, c_int32)(world, jointGroup)
+    else:
+        return loadOde('dJointCreateFixed', dJointID, dWorldID, dJointGroupID)(world, jointGroup)
+
 dJointCreateNull = loadOde('dJointCreateNull', dJointID, dWorldID, dJointGroupID)
-dJointCreateAMotor = loadOde('dJointCreateAMotor', dJointID, dWorldID, dJointGroupID)
+
+def dJointCreateAMotor(world, jointGroup):
+    if isinstance(jointGroup, int):
+        return loadOde('dJointCreateAMotor', dJointID, dWorldID, c_int32)(world, jointGroup)
+    else:
+        return loadOde('dJointCreateAMotor', dJointID, dWorldID, dJointGroupID)(world, jointGroup)
+
 dJointCreateLMotor = loadOde('dJointCreateLMotor', dJointID, dWorldID, dJointGroupID)
-dJointCreatePlane2D = loadOde('dJointCreatePlane2D', dJointID, dWorldID, dJointGroupID)
+
+def dJointCreatePlane2D(world, jointGroup):
+    if isinstance(jointGroup, int):
+        return loadOde('dJointCreatePlane2D', dJointID, dWorldID, c_int32)(world, jointGroup)
+    else:
+        return loadOde('dJointCreatePlane2D', dJointID, dWorldID, dJointGroupID)(world, jointGroup)
+
 dJointCreateDBall = loadOde('dJointCreateDBall', dJointID, dWorldID, dJointGroupID)
 dJointCreateDHinge = loadOde('dJointCreateDHinge', dJointID, dWorldID, dJointGroupID)
 dJointCreateTransmission = loadOde('dJointCreateTransmission', dJointID, dWorldID, dJointGroupID)
@@ -203,7 +237,13 @@ dJointGroupCreate = loadOde('dJointGroupCreate', dJointGroupID, c_int32)
 dJointGroupDestroy = loadOde('dJointGroupDestroy', None, dJointGroupID)
 dJointGroupEmpty = loadOde('dJointGroupEmpty', None, dJointGroupID)
 dJointGetNumBodies = loadOde('dJointGetNumBodies', c_int32, dJointID)
-dJointAttach = loadOde('dJointAttach', None, dJointID, dBodyID, dBodyID)
+
+def dJointAttach(joint, body1, body2):
+    if isinstance(body2, int):
+        return loadOde('dJointAttach', None, dJointID, dBodyID, c_int32)(joint, body1, body2)
+    else:
+        return loadOde('dJointAttach', None, dJointID, dBodyID, dBodyID)(joint, body1, body2)
+
 dJointEnable = loadOde('dJointEnable', None, dJointID)
 dJointDisable = loadOde('dJointDisable', None, dJointID)
 dJointIsEnabled = loadOde('dJointIsEnabled', c_int32, dJointID)
